==> bfilter-0.10.3.tar.gz: bfilter-0.10.3/main/HtmlResponseFilter.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "HtmlResponseFilter.h"
#include "HtmlProcessor.h"
#include "ResponseFilterChain.h"
#include "RequestPtr.h"
#include "RequestTag.h"
#include "SplittableBuffer.h"
#include "HttpResponseMetadata.h"
#include "HttpHeadersCollection.h"
#include <memory>

using namespace std;

HtmlResponseFilter::HtmlResponseFilter(
	ResponseFilterChain& chain, HtmlProcessor& processor,
	ConstRequestPtr const& request, bool xhtml_content)
:	ResponseFilterBase(chain),
	m_rProcessor(processor)
{
	m_rProcessor.setRelatedInfo(request, xhtml_content);
}

HtmlResponseFilter::~HtmlResponseFilter()
{
	m_rProcessor.reset();
}

void
HtmlResponseFilter::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
{
	metadata->headers().removeHeader(BString("Content-MD5"));
	metadata->setBodyStatus(HttpResponseMetadata::BODY_SIZE_UNKNOWN);
	getRequestTag()->flags().set(RequestTag::RESPONSE_MODIFIED);
	outputMetadata(metadata);
}

void
HtmlResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
{
	m_rProcessor.consume(data, eof);
	if (!m_rProcessor.processedData().data().empty() || eof) {
		SplittableBuffer data;
		m_rProcessor.processedData().swapData(data);
		outputBodyData(data, eof);
	}
}

==> bfilter-1.0.9.tar.gz: bfilter-1.0.9/main/HtmlResponseFilter.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "HtmlResponseFilter.h"
#include "HtmlProcessor.h"
#include "ResponseFilterChain.h"
#include "RequestPtr.h"
#include "RequestTag.h"
#include "SplittableBuffer.h"
#include "HttpResponseMetadata.h"
#include "HttpHeadersCollection.h"
#include <memory>

using namespace std;

HtmlResponseFilter::HtmlResponseFilter(
	ResponseFilterChain& chain, HtmlProcessor& processor,
	ConstRequestPtr const& request, bool xhtml_content)
:	ResponseFilterBase(chain),
	m_rProcessor(processor)
{
	bool bf_analyze = getRequestTag()->flags().isSet(RequestTag::REQUEST_ANALYZE);
	m_rProcessor.setRelatedInfo(request, xhtml_content, bf_analyze);
}

HtmlResponseFilter::~HtmlResponseFilter()
{
	m_rProcessor.reset();
}

void
HtmlResponseFilter::processMetadata(auto_ptr<HttpResponseMetadata> metadata)
{
	metadata->headers().removeHeader(BString("Content-MD5"));
	metadata->setBodyStatus(HttpResponseMetadata::BODY_SIZE_UNKNOWN);
	getRequestTag()->flags().set(RequestTag::RESPONSE_MODIFIED);
	outputMetadata(metadata);
}

void
HtmlResponseFilter::processBodyData(SplittableBuffer& data, bool eof)
{
	m_rProcessor.consume(data, eof);
	if (!m_rProcessor.processedData().data().empty() || eof) {
		SplittableBuffer data;
		m_rProcessor.processedData().swapData(data);
		outputBodyData(data, eof);
	}
}
